#' Datasets
#' `gff` contains a example of gff file used for test of
#' visualization mutations on gene model.
#'
#'
#' @name DataSet
#' @aliases gff
#' @docType data
#' @keywords datasets
NULL


#' Datasets
#' `seqs` contains a example of unaligned DNA sequences used for testing
#'
#'
#' @name DataSet
#' @aliases seqs
#' @docType data
#' @keywords datasets
NULL


#' Datasets
#' `hapResult` contains a example of unaligned DNA sequences used for testing
#'
#'
#' @name DataSet
#' @aliases hapResult
#' @docType data
#' @keywords datasets
NULL


#' Datasets
#' `gt.geno` contains a example of genotype stored in table format
#'
#'
#' @name DataSet
#' @aliases gt.geno
#' @docType data
#' @keywords datasets
NULL


#' Datasets
#'
#' `pheno` contains a simulated test pheno data used for test of comparison
#' between different haps
#'
#'
#' @name DataSet
#' @aliases pheno
#' @docType data
#' @keywords datasets
NULL


#' Datasets
#'
#' `vcf`, a vcfR object provide a data set for test of `seq2hap()`.
#' `vcf` contains indels, snps, biallelic sites and multiallelic sites.
#'
#' @name DataSet
#' @aliases vcf
#' @docType data
#' @keywords datasets
NULL


#' Datasets
#'
#' `AccINFO` a data.frame provide addtional information of accessions,
#' including accession type, source and location.
#'
#' @name DataSet
#' @aliases AccINFO
#' @docType data
#' @keywords datasets
NULL
